from distutils.core import setup

setup(
    name = "PhotonHomeAssistant",
    version = "1.0.1",
    author = "Emil Rais",
    author_email = "kongvman@hotmail.com",
    url = "https://pypi.python.org/pypi/PhotonHomeAssistant"
)
